==> nui_core-0.0.3.tar.gz: lib/ui/component/nui_row.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:nui_core/code/nui_code_util.dart';

class NUIRow extends StatefulWidget {
  NUIRow({
    this.mainAxisAlignment: MainAxisAlignment.start,
    this.mainAxisSize: MainAxisSize.max,
    this.crossAxisAlignment: CrossAxisAlignment.center,
    this.textDirection,
    this.verticalDirection: VerticalDirection.down,
    this.textBaseline: TextBaseline.alphabetic,
    @required this.children,
    this.showDividerStart: false,
    this.showDividerEnd: false,
    this.showDividerMiddle: true,
    @required this.divider,
    Key key
  }): super(key: key);

  final MainAxisAlignment mainAxisAlignment;
  final MainAxisSize mainAxisSize;
  final CrossAxisAlignment crossAxisAlignment;
  final TextDirection textDirection;
  final VerticalDirection verticalDirection;
  final TextBaseline textBaseline;
  final List<Widget> children;
  final VerticalDivider divider;
  final bool showDividerMiddle;
  final bool showDividerStart;
  final bool showDividerEnd;

  @override
  _NUIRowState createState() => _NUIRowState();
}

class _NUIRowState extends State<NUIRow> {
  @override
  Widget build(BuildContext context) {
    return Row(
      mainAxisSize: widget.mainAxisSize,
      mainAxisAlignment: widget.mainAxisAlignment,
      crossAxisAlignment: widget.crossAxisAlignment,
      textDirection: widget.textDirection,
      textBaseline: widget.textBaseline,
      verticalDirection: widget.verticalDirection,
      children: widget.divider != null ? _generateListWithDividers() : widget.children,
    );
  }

  List<Widget> _generateListWithDividers(){
    final items = List<Widget>();
    if(widget.showDividerStart) items.add(widget.divider);
    if(widget.showDividerMiddle) {
      loop(widget.children, (Widget data, int index, bool isFirst, bool isLast) {
        items.add(data);
        if(!isLast){
          items.add(widget.divider);
        }
      });
    }
    else{
      items.addAll(widget.children);
    }
    if(widget.showDividerEnd) items.add(widget.divider);
    return items;
  }
}

==> nui_core-0.0.28.tar.gz: lib/ui/component/nui_row.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:nui_core/code/nui_code_util.dart';

class NUIRow extends StatefulWidget {
  NUIRow({
    this.mainAxisAlignment: MainAxisAlignment.start,
    this.mainAxisSize: MainAxisSize.max,
    this.crossAxisAlignment: CrossAxisAlignment.center,
    this.textDirection,
    this.verticalDirection: VerticalDirection.down,
    this.textBaseline: TextBaseline.alphabetic,
    @required this.children,
    this.showDividerStart: false,
    this.showDividerEnd: false,
    this.showDividerMiddle: true,
    @required this.divider,
    Key key
  }): super(key: key);

  final MainAxisAlignment mainAxisAlignment;
  final MainAxisSize mainAxisSize;
  final CrossAxisAlignment crossAxisAlignment;
  final TextDirection textDirection;
  final VerticalDirection verticalDirection;
  final TextBaseline textBaseline;
  final List<Widget> children;
  final VerticalDivider divider;
  final bool showDividerMiddle;
  final bool showDividerStart;
  final bool showDividerEnd;

  @override
  _NUIRowState createState() => _NUIRowState();
}

class _NUIRowState extends State<NUIRow> {
  List<Widget> _filterChildren(){
    final children = List<Widget>();
    widget.children?.forEach((element) {
      if(element != null) children.add(element);
    });
    return children;
  }

  @override
  Widget build(BuildContext context) {
    return Row(
      mainAxisSize: widget.mainAxisSize,
      mainAxisAlignment: widget.mainAxisAlignment,
      crossAxisAlignment: widget.crossAxisAlignment,
      textDirection: widget.textDirection,
      textBaseline: widget.textBaseline,
      verticalDirection: widget.verticalDirection,
      children: widget.divider != null ? _generateListWithDividers() : _filterChildren(),
    );
  }

  List<Widget> _generateListWithDividers(){
    final items = List<Widget>();
    if(widget.showDividerStart) items.add(widget.divider);
    if(widget.showDividerMiddle) {
      loop(_filterChildren(), (Widget data, int index, bool isFirst, bool isLast) {
        items.add(data);
        if(!isLast){
          items.add(widget.divider);
        }
      });
    }
    else{
      items.addAll(_filterChildren());
    }
    if(widget.showDividerEnd) items.add(widget.divider);
    return items;
  }
}
